==> igniteui-react-charts-18.6.0.tgz: package/esm5/lib/PriceVolumeTrendIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { PriceVolumeTrendIndicatorStrategy } from "./PriceVolumeTrendIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var PriceVolumeTrendIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PriceVolumeTrendIndicator, _super);
    function PriceVolumeTrendIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PriceVolumeTrendIndicator.prototype.bc = function () {
        return new PriceVolumeTrendIndicator();
    };
    PriceVolumeTrendIndicator.prototype.get_y0 = function () {
        return new PriceVolumeTrendIndicatorStrategy();
    };
    Object.defineProperty(PriceVolumeTrendIndicator.prototype, "y0", {
        get: function () {
            return this.get_y0();
        },
        enumerable: false,
        configurable: true
    });
    PriceVolumeTrendIndicator.prototype.get_zd = function () {
        return PriceVolumeTrendIndicator.$;
    };
    Object.defineProperty(PriceVolumeTrendIndicator.prototype, "zd", {
        get: function () {
            return this.get_zd();
        },
        enumerable: false,
        configurable: true
    });
    PriceVolumeTrendIndicator.$t = markType(PriceVolumeTrendIndicator, 'PriceVolumeTrendIndicator', StrategyBasedIndicator.$);
    return PriceVolumeTrendIndicator;
}(StrategyBasedIndicator));
export { PriceVolumeTrendIndicator };

==> igniteui-react-charts-18.7.2.tgz: package/esm5/lib/PriceVolumeTrendIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { PriceVolumeTrendIndicatorStrategy } from "./PriceVolumeTrendIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var PriceVolumeTrendIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PriceVolumeTrendIndicator, _super);
    function PriceVolumeTrendIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PriceVolumeTrendIndicator.prototype.bi = function () {
        return new PriceVolumeTrendIndicator();
    };
    PriceVolumeTrendIndicator.prototype.get_abn = function () {
        return new PriceVolumeTrendIndicatorStrategy();
    };
    Object.defineProperty(PriceVolumeTrendIndicator.prototype, "abn", {
        get: function () {
            return this.get_abn();
        },
        enumerable: false,
        configurable: true
    });
    PriceVolumeTrendIndicator.prototype.get_ab0 = function () {
        return PriceVolumeTrendIndicator.$;
    };
    Object.defineProperty(PriceVolumeTrendIndicator.prototype, "ab0", {
        get: function () {
            return this.get_ab0();
        },
        enumerable: false,
        configurable: true
    });
    PriceVolumeTrendIndicator.$t = markType(PriceVolumeTrendIndicator, 'PriceVolumeTrendIndicator', StrategyBasedIndicator.$);
    return PriceVolumeTrendIndicator;
}(StrategyBasedIndicator));
export { PriceVolumeTrendIndicator };
